##  Overview
With metrics, you can store time series data in SAP LeanIX and create interactive charts to display the data. In addition the data can be linked to Fact Sheets, presented on the Dashboard or be displayed within the "Reports" area.
To navigate to metrics, in the administration area, go to the Metrics section.
![Metrics Page in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275464377a441014bdb78e89c138948d_LowRes.png)
Metrics Page in the Administration Area
